<template>
  <div class="page-content corporate-customers">
    <transition-group
      :name="transitionName"
      appear
      class="transition-group"
      tag="div"
    >
      <!--   表格页面   -->
      <table-page
        v-show="componentName === 'TablePage'"
        key="TablePage"
        :componentName="componentName"
        @changePage="changePage"
      />
    </transition-group>
  </div>
</template>

<script>
import TablePage from './components/TablePage/index.vue'
import PubSub from 'pubsub-js'

export default {
  name: 'EventStatistics',
  components: {TablePage},
  data() {
    return {
      componentName: 'TablePage',
      pubSub: null,
      transitionName: ''
    }
  },
  mounted() {
    // 添加自定义面包屑pub-sub
    this.pubSub = PubSub.subscribe('breadcrumb-click', (_, item) => {
      if (item.isCurrentRoute) this.componentName = 'TablePage'
    })
  },
  methods: {
    /**
     * 改变页面
     * @param {String} pageName 显示页面标识符
     * @param {Function} [done] 回调函数，保证页面挂载后执行的逻辑
     * @param {String} [type] 面包屑标题
     * */
    changePage(pageName = '', done, type = '') {
      this.componentName = pageName
      this.transitionName =
        this.transitionName === 'fold-right' ? 'fold-left' : 'fold-right'
      done && done()
      switch (pageName) {
        case 'TablePage':
          PubSub.publish('go-back')
          break
      }
    }
  },
  beforeDestroy() {
    // 在组件销毁之前 清除订阅消息
    PubSub.unsubscribe(this.pubSub)
  }
}
</script>

<style lang="scss" scoped></style>
